==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Clicca per accedere al dispositivo da altre applicazioni.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="54"/>
        <source>Click to eject this disc.</source>
        <translation>Clicca per espellere il disco.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="160"/>
        <source>Removable media/devices manager</source>
        <translation>Gestore di dispositivi removibili</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="218"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Il dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; è connesso.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="235"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Il dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; è stato rimosso.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="316"/>
        <source>No devices Available.</source>
        <translation>Nessun dispositivo disponibile.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Impostazioni del gestore di dispositivi removibili Razor</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Quando un dispositivo è connesso</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>Mostra menu in nuova finestra</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Show info</source>
        <translation>Mostra informazioni</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="46"/>
        <source>Do nothing</source>
        <translation>Non fare nulla</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Fai clic per accedere al dispositivo da altre applicazioni.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Fai clic per espellere il disco.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Gestore dei dispositivi rimovibili</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Il dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; è connesso.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Il dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; è stato rimosso.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation>Nessun dispositivo disponibile</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Impostazioni del gestore dei dispositivi rimovibili di Razor</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Quando un dispositivo è connesso </translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Menu a comparsa</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Mostra informazioni</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Non fare nulla</translation>
    </message>
</context>
</TS>
